@@ -59,7 +59,7 @@ impl Build {
             Lua51 => source_dir_base.join("lua-5.1.5"),
             Lua52 => source_dir_base.join("lua-5.2.4"),
             Lua53 => source_dir_base.join("lua-5.3.6"),
-            Lua54 => source_dir_base.join("lua-5.4.1"),
+            Lua54 => source_dir_base.join("lua-5.4.3"),
         };
 
         if lib_dir.exists() {
@@ -87,6 +87,12 @@ impl Build {
             _ if target.contains("freebsd") => {
                 config.define("LUA_USE_LINUX", None);
             }
+            _ if target.contains("netbsd") => {
+                config.define("LUA_USE_LINUX", None);
+            }
+            _ if target.contains("openbsd") => {
+                config.define("LUA_USE_LINUX", None);
+            }
             _ if target.contains("apple-darwin") => {
                 match version {
                     Lua51 => config.define("LUA_USE_LINUX", None),
@@ -102,6 +108,12 @@ impl Build {
 
         if let Lua54 = version {
             config.define("LUA_COMPAT_5_3", None);
+            #[cfg(feature = "ucid")]
+            config.define("LUA_UCID", None);
+        }
+
+        if cfg!(debug_assertions) {
+            config.define("LUA_USE_APICHECK", None);
         }
 
         let lib_name = match version {
